==> cenote_0.9.1_20071020.zip: cenote/setup/index2.php <==
<?php
if(file_exists("../configuration.php")){
	header("Location: ./index.php");
}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
<title>CENOTE SETUP TOOL(MODULE)</title>
<style type="text/css">
<!--
body {
	margin-left: 0px;
	margin-top: 0px;
	margin-right: 0px;
	margin-bottom: 0px;
}
.style1 {
	font-size: 24px;
	font-style: italic;
	text-align: center;
}
.style2 {font-size: 14px; font-style: bold; text-align: left;}

.style3 {font-size: 14px; font-style: normal; text-align: center;}

.red {color: #F00; font-style: bold; background-color:#FAA}

.blue {color: #00F; font-style: bold; background-color:#AAF}
-->
</style></head>

<body>
<form id="setup" name="setup" method="post" action="index3.php"> 

<table width="100%" border="0">
  <tr>
    <td height="362" valign="top"><div align="center">
      <p><img src="./images/cenote_logo.png" width="350" height="100" /></p>
      <p class="style1">～SETUP TOOL～ </p>
      <p class="style1">１．モジュールの書き込み権限確認</p>
      <p class="style3">以下のディレクトリはシステムが稼動中に利用します</p>
<?php
		$module = array();
		
		
		$ix = 0;
		if(is_writable("../")) {
			$f = "./";
			$module[$f] = "OK";
		} else {
			$f = "./";
			$module[$f] = "NG";
			$ix = 1;
		}
		if(is_writable("../images")) {
			$f = "./images";
			$module[$f] = "OK";
		} else {
			$f = "./images";
			$module[$f] = "NG";
			$ix = 1;
		}
		if(is_writable("../cenote/compile")) {
			$f = "./cenote/compile";
			$module[$f] = "OK";
		} else {
			$f = "./cenote/compile";
			$module[$f] = "NG";
			$ix = 1;
		}
		if(is_writable("../cenote/cache")) {
			$f = "./cenote/cache";
			$module[$f] = "OK";
		} else {
			$f = "./cenote/cache";
			$module[$f] = "NG";
			$ix = 1;
		}

		echo "<table>";
		foreach($module as $key => $value){
			echo "<tr><td align=\"left\" width=\"200px\">";
			echo $key;
			echo "</td>";
			if($value == "NG"){
				echo "<td width=\"50px\"><span class=\"red\">".$value."</span>";
			}else{
				echo "<td width=\"50px\"><span class=\"blue\">".$value."</span>";
			}
			echo "</td></tr>";
		}
		echo "</table>";
		echo "<br />";
		if($ix == 0){
			echo "<span>すべて書き込み可能です。</span><br />";
			echo "<input type=\"submit\" name=\"Submit\" value=\"次へ\" />";
		}

?>

      <p>&nbsp;</p>
    </div></td>
  </tr>
</table>
</form>
</body>
</html>

==> cenote_0.9.3_20071026.zip: cenote/setup/index2.php <==
<?php
if(file_exists("../configuration.php")){
	header("Location: ./index.php");
}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
<title>CENOTE SETUP TOOL(MODULE)</title>
<style type="text/css">
<!--
body {
	margin-left: 0px;
	margin-top: 0px;
	margin-right: 0px;
	margin-bottom: 0px;
}
.style1 {
	font-size: 24px;
	font-style: italic;
	text-align: center;
}
.style2 {font-size: 14px; font-style: bold; text-align: left;}

.style3 {font-size: 14px; font-style: normal; text-align: center;}

.red {color: #F00; font-style: bold; background-color:#FAA}

.blue {color: #00F; font-style: bold; background-color:#AAF}
table.con {
	border-style: solid;
    border-width: 1px;
    border-color: #666;
}

th.con {
	width:100%;
	height:21px;
	color: #EEE;
	background-color: #CCC;
	border-width: 1px;
	margin: 0px;
	padding: 0px;
	text-align:left;
	font-size: 12px;
	font-weight: bold;
}
td.con {
	height:25px;
	font-size: 12px;
	font-style: normal;
	margin: 0px;
	background-color: #DDD;
	border-width: 1px;
	padding: 1px;
	color: #000;
}
-->
</style></head>

<body>
<form id="setup" name="setup" method="post" action="index3.php"> 

<table width="100%" border="0">
  <tr>
    <td height="362" valign="top"><div align="center">
      <p><img src="./images/cenote_logo.png" width="350" height="100" /></p>
      <p class="style1">～SETUP TOOL～ </p>
      <p class="style1">１．モジュールの書き込み権限確認</p>
      <p class="style3">以下のディレクトリはシステムが稼動中に利用します</p>
<?php
		$module = array();
		
		
		$ix = 0;
		if(is_writable("../")) {
			$f = "./";
			$module[$f] = "OK";
		} else {
			$f = "./";
			$module[$f] = "NG";
			$ix = 1;
		}
		if(is_writable("../cenote/compile")) {
			$f = "./cenote/compile";
			$module[$f] = "OK";
		} else {
			$f = "./cenote/compile";
			$module[$f] = "NG";
			$ix = 1;
		}
		if(is_writable("../cenote/cache")) {
			$f = "./cenote/cache";
			$module[$f] = "OK";
		} else {
			$f = "./cenote/cache";
			$module[$f] = "NG";
			$ix = 1;
		}

		echo "<table class=\"con\">";
		foreach($module as $key => $value){
			echo "<tr><td  class=\"con\" align=\"left\" width=\"200px\">";
			echo $key;
			echo "</td>";
			if($value == "NG"){
				echo "<td  class=\"con\" width=\"50px\"><span class=\"red\">".$value."</span>";
			}else{
				echo "<td  class=\"con\" width=\"50px\"><span class=\"blue\">".$value."</span>";
			}
			echo "</td></tr>";
		}
		echo "</table>";
		echo "<br />";
		if($ix == 0){
			echo "<span>すべて書き込み可能です。</span><br />";
			echo "<input type=\"submit\" name=\"Submit\" value=\"次へ\" />";
		}

?>

      <p>&nbsp;</p>
    </div></td>
  </tr>
</table>
</form>
</body>
</html>
